==> activity-center-api-3.0.2-20180825.013927-1-sources.jar: cn/com/duiba/activity/center/api/tool/RedisKeySpace.java <==
package cn.com.duiba.activity.center.api.tool;

/**
 * 用于管理使用Redis的所有key前缀，避免业务key重复<br/>
 * 例如<br/>
 * K001("xxx业务缓存"),<br/>
 * K002("xxx业务分布式锁"), <br/>
 * K003("xxx业务计数器");<br/>
 * 
 * @author houwen
 */
public enum RedisKeySpace {
	/** 活动每日参与次数 */
	K001("活动每日参与次数"),
	/** 活动每日免费次数 */
	K002("活动每日免费次数"),
	/**签到体系活动签到锁key**/
	K003("签到体系活动签到锁key"),
	/**活动工具皮肤默认数据key**/
	K004("活动工具皮肤默认数据"),
	/**入库活动缓存key**/
	K005("入库活动缓存key"),
	/**更新签到统计数据锁**/
	K006("更新签到统计数据锁key"),
	/**插件活动dto缓存key**/
	K007("插件活动dto缓存key"),
	/**客服配置缓存key**/
	K008("客服配置缓存key"),
	/**活动奖品发放数量**/
	K009("活动奖品发放数量"),
	/**集卡发奖用户锁,用户奖项扣库存时对用户枷锁避免任何的数据变更引起的奖项超发**/
	K010("集卡发奖用户锁"),
	/**多游戏排名基本配置**/
	K011("多游戏排名基本配置"),
	/**多游戏排名一个配置下面的活动列表**/
	K012("多游戏排名一个配置下面的活动列表"),
	/**多游戏排名中一个活动对应的配置项id**/
	K013("多游戏排名中一个活动对应的配置项id"),
	/**多游戏排名中一个配置项用户的总分**/
	K014("多游戏排名中一个配置项用户的总分"),
	/** 直冲奖品防刷每日类型key */
	K015("多游戏排名中一个配置项用户的总分"),
	/**奖项排名中一个配置项用户的总分**/
	K016("奖项排名中一个配置项用户的总分"),
	/**集卡发放-需要获取的后几张卡片数量**/
	K017("需要获取的后几张卡片数量"),
	/**集卡发放-发放概率**/
	K018("发放概率"),
	/**集卡发放-每张卡片单个用户发放上限**/
	K019("每张卡片单个用户发放上限"),
	/** 记录首页弹层曝光过的appId */
	K020("时间段内首页弹层活动曝光记录"),
    K021("热血街舞打call-单个用户不同明星分数"),
	K022("热血街舞打call-单个明星总分"),
	K023("开心码赛事配置信息id"),
	K024("开心码奖项配置信息id"),
	K025("开心码奖项配置信息上的期次id"),
	K026("开心码期次配置信息id"),
	K027("集卡配置信息id"),
	K028("活动工具奖项批量查询"),

	K030("ActivityPrizeOptionService.queryActivityOptionsByConfigId"),
	K031("ActivityPrizeOptionService.find"),
	K032("RemoteRecommendService.findRecommendSkin"),
	K033("OperatingActivityService.findByAppIdAndDuibaHdtoolIdAndDeleted"),
	K034("搜狐咨询收集唇印领奖记录按手机号查询"),
	K035("搜狐咨询收集唇印领奖记录按用户id查询"),

	K036("种红包按活动id查询缓存"),
	K037("种红包成熟时间配置缓存"),
	K038("种红包查询可提现用户列表缓存"),
	K039("种红包查询可提现用户数量缓存"),

	K040("PopupActivityBrick缓存key"),
	K041("皮肤md5值"),
	K042("活动每周参与次数"),
	K043("活动每月参与次数"),
	K044("签到配置,id"),
	K045("签到配置,appId"),
    K046("游戏子订单拓展信息缓存"),

	K050("签到皮肤模板数据缓存"),
	K051("用户游戏记录"),
	K052("用户游戏记录ID映射缓存"),

	K055("猜红包用户最近开的红包"),
	K056("猜红包用户红包信息"),
	K057("种红包用户当天已种红包数量"),
	K058("种红包用户当天种的红包可领金额"),
	K059("种红包可提现标记用户登录标记"),

	K060("BetGroupRelationServiceImpl.listByBetIdAndGroupIds"),
    K061("AppGroupRelationServiceImpl.listByAppId"),
	K062("BetConfigServiceImpl.findById"),
	K063("BetGroupRelationServiceImpl.listByGroupIdWithCache"),
    K064("BetGroupRelationServiceImpl.countByGroupIdWithCache"),
    K065("BetConfigServiceImpl.listByIdsWitchCache"),
    K066("BetOptionServiceImpl.listByBetIds"),
    K067("BetResultServiceImpl.listByBetIdsWithCache"),
	K068("BetConfigServiceImpl.getListByStatusAndEndTime"),

	K070("博彩活动选项缓存"),
    K071("博彩活动选项积分缓存"),
	K072("博彩活动某一活动的用户参与记录"),
    K073("博彩活动获取某一个活动组活动列表"),
	K074("博彩活动今日活动首页缓存"),
    K075("博彩活动往日竞猜首页缓存"),
    K076("博彩活动首页竞猜单个活动缓存"),
	K077("博彩活动最近4天的活动id列表"),
	K078("pk活动选项押注次数"),
	K079("pk用户弹窗"),
	K080("betConfigService.listByBetIdsOrderByEndTimeAndIdWithCache"),
	KO81("漫漫漫画偶像成长计划用户今日投票次数"),
	KO82("漫漫漫画偶像成长计划角色今日得票数"),
	KO83("漫漫漫画偶像成长计划角色总得票数"),

	K090("陌陌推送登陆用户"),
	K091("陌陌推送未领奖用户"),

	K092("多游戏排名中一个分榜信息对应的配置项id"),
	K093("多游戏排行榜分榜维度数据集"),
	K094("多游戏排行榜分榜最后一名分数"),
	K095("多游戏排行榜分榜维度次数序列-用于同分排序"),
    ;

	/**
	 * 应用名称
	 */
	private static final String SPACE = "AC";

	private String desc;

	RedisKeySpace(String description) {
		this.desc = description;
	}

	public String getDesc() {
		return desc;
	}

	/**
	 * 拼接key前置
	 */
	@Override
	public String toString() {
		return SPACE + "_" + super.toString() + "_";
	}

}

==> activity-center-api-3.1.19-20181030.033812-1-sources.jar: cn/com/duiba/activity/center/api/tool/RedisKeySpace.java <==
package cn.com.duiba.activity.center.api.tool;

/**
 * 用于管理使用Redis的所有key前缀，避免业务key重复<br/>
 * 例如<br/>
 * K001("xxx业务缓存"),<br/>
 * K002("xxx业务分布式锁"), <br/>
 * K003("xxx业务计数器");<br/>
 * 
 * @author houwen
 */
public enum RedisKeySpace {
	/** 活动每日参与次数 */
	K001("活动每日参与次数"),
	/** 活动每日免费次数 */
	K002("活动每日免费次数"),
	/**签到体系活动签到锁key**/
	K003("签到体系活动签到锁key"),
	/**活动工具皮肤默认数据key**/
	K004("活动工具皮肤默认数据"),
	/**入库活动缓存key**/
	K005("入库活动缓存key"),
	/**更新签到统计数据锁**/
	K006("更新签到统计数据锁key"),
	/**插件活动dto缓存key**/
	K007("插件活动dto缓存key"),
	/**客服配置缓存key**/
	K008("客服配置缓存key"),
	/**活动奖品发放数量**/
	K009("活动奖品发放数量"),
	/**集卡发奖用户锁,用户奖项扣库存时对用户枷锁避免任何的数据变更引起的奖项超发**/
	K010("集卡发奖用户锁"),
	/**多游戏排名基本配置**/
	K011("多游戏排名基本配置"),
	/**多游戏排名一个配置下面的活动列表**/
	K012("多游戏排名一个配置下面的活动列表"),
	/**多游戏排名中一个活动对应的配置项id**/
	K013("多游戏排名中一个活动对应的配置项id"),
	/**多游戏排名中一个配置项用户的总分**/
	K014("多游戏排名中一个配置项用户的总分"),
	/** 直冲奖品防刷每日类型key */
	K015("多游戏排名中一个配置项用户的总分"),
	/**奖项排名中一个配置项用户的总分**/
	K016("奖项排名中一个配置项用户的总分"),
	/**集卡发放-需要获取的后几张卡片数量**/
	K017("需要获取的后几张卡片数量"),
	/**集卡发放-发放概率**/
	K018("发放概率"),
	/**集卡发放-每张卡片单个用户发放上限**/
	K019("每张卡片单个用户发放上限"),
	/** 记录首页弹层曝光过的appId */
	K020("时间段内首页弹层活动曝光记录"),
    K021("热血街舞打call-单个用户不同明星分数"),
	K022("热血街舞打call-单个明星总分"),
	K023("开心码赛事配置信息id"),
	K024("开心码奖项配置信息id"),
	K025("开心码奖项配置信息上的期次id"),
	K026("开心码期次配置信息id"),
	K027("集卡配置信息id"),
	K028("活动工具奖项批量查询"),
	K029("种红包app与种红包活动映射关系"),
	K030("ActivityPrizeOptionService.queryActivityOptionsByConfigId"),
	K031("ActivityPrizeOptionService.find"),
	K032("RemoteRecommendService.findRecommendSkin"),
	K033("OperatingActivityService.findByAppIdAndDuibaHdtoolIdAndDeleted"),
	K034("搜狐咨询收集唇印领奖记录按手机号查询"),
	K035("搜狐咨询收集唇印领奖记录按用户id查询"),
	K036("种红包按活动id查询缓存"),
	K037("种红包成熟时间配置缓存"),
	K038("种红包查询可提现用户列表缓存"),
	K039("种红包查询可提现用户数量缓存"),
	K040("PopupActivityBrick缓存key"),
	K041("皮肤md5值"),
	K042("活动每周参与次数"),
	K043("活动每月参与次数"),
	K044("签到配置,id"),
	K045("签到配置,appId"),
    K046("游戏子订单拓展信息缓存"),
	K047("开心码奖项列表配置信息上的期次id"),

	K050("签到皮肤模板数据缓存"),
	K051("用户游戏记录"),
	K052("用户游戏记录ID映射缓存"),

	K054("种红包用户当日是否第一次收割红包"),
	K055("猜红包用户最近开的红包"),
	K056("猜红包用户红包信息"),
	K057("种红包用户当天已种红包数量"),
	K058("种红包用户当天种的红包可领金额"),
	K059("种红包可提现标记用户登录标记"),

	K060("BetGroupRelationServiceImpl.listByBetIdAndGroupIds"),
    K061("AppGroupRelationServiceImpl.listByAppId"),
	K062("BetConfigServiceImpl.findById"),
	K063("BetGroupRelationServiceImpl.listByGroupIdWithCache"),
    K064("BetGroupRelationServiceImpl.countByGroupIdWithCache"),
    K065("BetConfigServiceImpl.listByIdsWitchCache"),
    K066("BetOptionServiceImpl.listByBetIds"),
    K067("BetResultServiceImpl.listByBetIdsWithCache"),
	K068("BetConfigServiceImpl.getListByStatusAndEndTime"),

	K070("博彩活动选项缓存"),
    K071("博彩活动选项积分缓存"),
	K072("博彩活动某一活动的用户参与记录"),
    K073("博彩活动获取某一个活动组活动列表"),
	K074("博彩活动今日活动首页缓存"),
    K075("博彩活动往日竞猜首页缓存"),
    K076("博彩活动首页竞猜单个活动缓存"),
	K077("博彩活动最近4天的活动id列表"),
	K078("pk活动选项押注次数"),
	K079("pk用户弹窗"),
	K080("betConfigService.listByBetIdsOrderByEndTimeAndIdWithCache"),
	KO81("漫漫漫画偶像成长计划用户今日投票次数"),
	KO82("漫漫漫画偶像成长计划角色今日得票数"),
	KO83("漫漫漫画偶像成长计划角色总得票数"),

	K090("陌陌推送登陆用户"),
	K091("陌陌推送未领奖用户"),

	K092("多游戏排名中一个分榜信息对应的配置项id"),
	K093("多游戏排行榜分榜维度数据集"),
	K094("多游戏排行榜分榜最后一名分数"),
	K095("多游戏排行榜分榜维度次数序列-用于同分排序"),

	K096("app当月游戏中心配置的总金额"),

	K100("新游戏中心配置缓存"),
	K101("新游戏中心定向缓存"),
	K102("新游戏中心赛季缓存"),

	K110("种红包当前用户剩余可中红包次数"),
	K111("种红包当前用户剩余可种植红包次数"),

	K120("拼团按拼团id获取团信息"),
	K121("拼团按拼团id列表批量获取拼团信息"),
	K122("拼团按拼团商品id和状态批量获取团信息"),
	K123("拼团按appId、拼团活动配置id、状态批量获取团信息"),
	K124("拼团活动配置"),
	K125("拼团根据自定义活动id(列表)拼团活动配置"),
	K126("拼团根据自定义活动id(详情)拼团活动配置"),
	K127("根据假用户id列表批量获取假用户信息"),
	K128("拼团根据商品id获取拼团商品"),
	K129("拼团根据商品id列表批量获取拼团商品"),
	K130("拼团按商品id列表和状态批量获取团信息"),
	K131("拼团按团id和用户id获取用户参团记录"),
	;

	/**
	 * 应用名称
	 */
	private static final String SPACE = "AC";

	private String desc;

	RedisKeySpace(String description) {
		this.desc = description;
	}

	public String getDesc() {
		return desc;
	}

	/**
	 * 拼接key前置
	 */
	@Override
	public String toString() {
		return SPACE + "_" + super.toString() + "_";
	}

}
